==> tekton-model-triggers-v1alpha1-6.2.0-sources.jar: io/fabric8/tekton/triggers/v1alpha1/TriggerInterceptorFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;

 /**
  * Generated
  */
public interface TriggerInterceptorFluent<A extends TriggerInterceptorFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildBitbucket instead.
   * @return The buildable object.
   */
  @Deprecated
  public BitbucketInterceptor getBitbucket();
  public BitbucketInterceptor buildBitbucket();
  public A withBitbucket(BitbucketInterceptor bitbucket);
  public Boolean hasBitbucket();
  public TriggerInterceptorFluent.BitbucketNested<A> withNewBitbucket();
  public TriggerInterceptorFluent.BitbucketNested<A> withNewBitbucketLike(BitbucketInterceptor item);
  public TriggerInterceptorFluent.BitbucketNested<A> editBitbucket();
  public TriggerInterceptorFluent.BitbucketNested<A> editOrNewBitbucket();
  public TriggerInterceptorFluent.BitbucketNested<A> editOrNewBitbucketLike(BitbucketInterceptor item);
  
  /**
   * This method has been deprecated, please use method buildCel instead.
   * @return The buildable object.
   */
  @Deprecated
  public CELInterceptor getCel();
  public CELInterceptor buildCel();
  public A withCel(CELInterceptor cel);
  public Boolean hasCel();
  public TriggerInterceptorFluent.CelNested<A> withNewCel();
  public TriggerInterceptorFluent.CelNested<A> withNewCelLike(CELInterceptor item);
  public TriggerInterceptorFluent.CelNested<A> editCel();
  public TriggerInterceptorFluent.CelNested<A> editOrNewCel();
  public TriggerInterceptorFluent.CelNested<A> editOrNewCelLike(CELInterceptor item);
  
  /**
   * This method has been deprecated, please use method buildGithub instead.
   * @return The buildable object.
   */
  @Deprecated
  public GitHubInterceptor getGithub();
  public GitHubInterceptor buildGithub();
  public A withGithub(GitHubInterceptor github);
  public Boolean hasGithub();
  public TriggerInterceptorFluent.GithubNested<A> withNewGithub();
  public TriggerInterceptorFluent.GithubNested<A> withNewGithubLike(GitHubInterceptor item);
  public TriggerInterceptorFluent.GithubNested<A> editGithub();
  public TriggerInterceptorFluent.GithubNested<A> editOrNewGithub();
  public TriggerInterceptorFluent.GithubNested<A> editOrNewGithubLike(GitHubInterceptor item);
  
  /**
   * This method has been deprecated, please use method buildGitlab instead.
   * @return The buildable object.
   */
  @Deprecated
  public GitLabInterceptor getGitlab();
  public GitLabInterceptor buildGitlab();
  public A withGitlab(GitLabInterceptor gitlab);
  public Boolean hasGitlab();
  public TriggerInterceptorFluent.GitlabNested<A> withNewGitlab();
  public TriggerInterceptorFluent.GitlabNested<A> withNewGitlabLike(GitLabInterceptor item);
  public TriggerInterceptorFluent.GitlabNested<A> editGitlab();
  public TriggerInterceptorFluent.GitlabNested<A> editOrNewGitlab();
  public TriggerInterceptorFluent.GitlabNested<A> editOrNewGitlabLike(GitLabInterceptor item);
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public A addToParams(Integer index,InterceptorParams item);
  public A setToParams(Integer index,InterceptorParams item);
  public A addToParams(io.fabric8.tekton.triggers.v1alpha1.InterceptorParams... items);
  public A addAllToParams(Collection<InterceptorParams> items);
  public A removeFromParams(io.fabric8.tekton.triggers.v1alpha1.InterceptorParams... items);
  public A removeAllFromParams(Collection<InterceptorParams> items);
  public A removeMatchingFromParams(Predicate<InterceptorParamsBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildParams instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<InterceptorParams> getParams();
  public List<InterceptorParams> buildParams();
  public InterceptorParams buildParam(Integer index);
  public InterceptorParams buildFirstParam();
  public InterceptorParams buildLastParam();
  public InterceptorParams buildMatchingParam(Predicate<InterceptorParamsBuilder> predicate);
  public Boolean hasMatchingParam(Predicate<InterceptorParamsBuilder> predicate);
  public A withParams(List<InterceptorParams> params);
  public A withParams(io.fabric8.tekton.triggers.v1alpha1.InterceptorParams... params);
  public Boolean hasParams();
  public A addNewParam(String name,Object value);
  public TriggerInterceptorFluent.ParamsNested<A> addNewParam();
  public TriggerInterceptorFluent.ParamsNested<A> addNewParamLike(InterceptorParams item);
  public TriggerInterceptorFluent.ParamsNested<A> setNewParamLike(Integer index,InterceptorParams item);
  public TriggerInterceptorFluent.ParamsNested<A> editParam(Integer index);
  public TriggerInterceptorFluent.ParamsNested<A> editFirstParam();
  public TriggerInterceptorFluent.ParamsNested<A> editLastParam();
  public TriggerInterceptorFluent.ParamsNested<A> editMatchingParam(Predicate<InterceptorParamsBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public InterceptorRef getRef();
  public InterceptorRef buildRef();
  public A withRef(InterceptorRef ref);
  public Boolean hasRef();
  public A withNewRef(String apiVersion,String kind,String name);
  public TriggerInterceptorFluent.RefNested<A> withNewRef();
  public TriggerInterceptorFluent.RefNested<A> withNewRefLike(InterceptorRef item);
  public TriggerInterceptorFluent.RefNested<A> editRef();
  public TriggerInterceptorFluent.RefNested<A> editOrNewRef();
  public TriggerInterceptorFluent.RefNested<A> editOrNewRefLike(InterceptorRef item);
  
  /**
   * This method has been deprecated, please use method buildWebhook instead.
   * @return The buildable object.
   */
  @Deprecated
  public WebhookInterceptor getWebhook();
  public WebhookInterceptor buildWebhook();
  public A withWebhook(WebhookInterceptor webhook);
  public Boolean hasWebhook();
  public TriggerInterceptorFluent.WebhookNested<A> withNewWebhook();
  public TriggerInterceptorFluent.WebhookNested<A> withNewWebhookLike(WebhookInterceptor item);
  public TriggerInterceptorFluent.WebhookNested<A> editWebhook();
  public TriggerInterceptorFluent.WebhookNested<A> editOrNewWebhook();
  public TriggerInterceptorFluent.WebhookNested<A> editOrNewWebhookLike(WebhookInterceptor item);
  public interface BitbucketNested<N> extends Nested<N>,BitbucketInterceptorFluent<TriggerInterceptorFluent.BitbucketNested<N>>{
    public N and();
    public N endBitbucket();
    
  }
  public interface CelNested<N> extends Nested<N>,CELInterceptorFluent<TriggerInterceptorFluent.CelNested<N>>{
    public N and();
    public N endCel();
    
  }
  public interface GithubNested<N> extends Nested<N>,GitHubInterceptorFluent<TriggerInterceptorFluent.GithubNested<N>>{
    public N and();
    public N endGithub();
    
  }
  public interface GitlabNested<N> extends Nested<N>,GitLabInterceptorFluent<TriggerInterceptorFluent.GitlabNested<N>>{
    public N and();
    public N endGitlab();
    
  }
  public interface ParamsNested<N> extends Nested<N>,InterceptorParamsFluent<TriggerInterceptorFluent.ParamsNested<N>>{
    public N and();
    public N endParam();
    
  }
  public interface RefNested<N> extends Nested<N>,InterceptorRefFluent<TriggerInterceptorFluent.RefNested<N>>{
    public N and();
    public N endRef();
    
  }
  public interface WebhookNested<N> extends Nested<N>,WebhookInterceptorFluent<TriggerInterceptorFluent.WebhookNested<N>>{
    public N and();
    public N endWebhook();
    
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.2-sources.jar: io/fabric8/tekton/triggers/v1alpha1/TriggerInterceptorFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;

 /**
  * Generated
  */
public interface TriggerInterceptorFluent<A extends TriggerInterceptorFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildBitbucket instead.
   * @return The buildable object.
   */
  @Deprecated
  public BitbucketInterceptor getBitbucket();
  public BitbucketInterceptor buildBitbucket();
  public A withBitbucket(BitbucketInterceptor bitbucket);
  public Boolean hasBitbucket();
  public TriggerInterceptorFluent.BitbucketNested<A> withNewBitbucket();
  public TriggerInterceptorFluent.BitbucketNested<A> withNewBitbucketLike(BitbucketInterceptor item);
  public TriggerInterceptorFluent.BitbucketNested<A> editBitbucket();
  public TriggerInterceptorFluent.BitbucketNested<A> editOrNewBitbucket();
  public TriggerInterceptorFluent.BitbucketNested<A> editOrNewBitbucketLike(BitbucketInterceptor item);
  
  /**
   * This method has been deprecated, please use method buildCel instead.
   * @return The buildable object.
   */
  @Deprecated
  public CELInterceptor getCel();
  public CELInterceptor buildCel();
  public A withCel(CELInterceptor cel);
  public Boolean hasCel();
  public TriggerInterceptorFluent.CelNested<A> withNewCel();
  public TriggerInterceptorFluent.CelNested<A> withNewCelLike(CELInterceptor item);
  public TriggerInterceptorFluent.CelNested<A> editCel();
  public TriggerInterceptorFluent.CelNested<A> editOrNewCel();
  public TriggerInterceptorFluent.CelNested<A> editOrNewCelLike(CELInterceptor item);
  
  /**
   * This method has been deprecated, please use method buildGithub instead.
   * @return The buildable object.
   */
  @Deprecated
  public GitHubInterceptor getGithub();
  public GitHubInterceptor buildGithub();
  public A withGithub(GitHubInterceptor github);
  public Boolean hasGithub();
  public TriggerInterceptorFluent.GithubNested<A> withNewGithub();
  public TriggerInterceptorFluent.GithubNested<A> withNewGithubLike(GitHubInterceptor item);
  public TriggerInterceptorFluent.GithubNested<A> editGithub();
  public TriggerInterceptorFluent.GithubNested<A> editOrNewGithub();
  public TriggerInterceptorFluent.GithubNested<A> editOrNewGithubLike(GitHubInterceptor item);
  
  /**
   * This method has been deprecated, please use method buildGitlab instead.
   * @return The buildable object.
   */
  @Deprecated
  public GitLabInterceptor getGitlab();
  public GitLabInterceptor buildGitlab();
  public A withGitlab(GitLabInterceptor gitlab);
  public Boolean hasGitlab();
  public TriggerInterceptorFluent.GitlabNested<A> withNewGitlab();
  public TriggerInterceptorFluent.GitlabNested<A> withNewGitlabLike(GitLabInterceptor item);
  public TriggerInterceptorFluent.GitlabNested<A> editGitlab();
  public TriggerInterceptorFluent.GitlabNested<A> editOrNewGitlab();
  public TriggerInterceptorFluent.GitlabNested<A> editOrNewGitlabLike(GitLabInterceptor item);
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public A addToParams(int index,InterceptorParams item);
  public A setToParams(int index,InterceptorParams item);
  public A addToParams(io.fabric8.tekton.triggers.v1alpha1.InterceptorParams... items);
  public A addAllToParams(Collection<InterceptorParams> items);
  public A removeFromParams(io.fabric8.tekton.triggers.v1alpha1.InterceptorParams... items);
  public A removeAllFromParams(Collection<InterceptorParams> items);
  public A removeMatchingFromParams(Predicate<InterceptorParamsBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildParams instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<InterceptorParams> getParams();
  public List<InterceptorParams> buildParams();
  public InterceptorParams buildParam(int index);
  public InterceptorParams buildFirstParam();
  public InterceptorParams buildLastParam();
  public InterceptorParams buildMatchingParam(Predicate<InterceptorParamsBuilder> predicate);
  public Boolean hasMatchingParam(Predicate<InterceptorParamsBuilder> predicate);
  public A withParams(List<InterceptorParams> params);
  public A withParams(io.fabric8.tekton.triggers.v1alpha1.InterceptorParams... params);
  public Boolean hasParams();
  public A addNewParam(String name,Object value);
  public TriggerInterceptorFluent.ParamsNested<A> addNewParam();
  public TriggerInterceptorFluent.ParamsNested<A> addNewParamLike(InterceptorParams item);
  public TriggerInterceptorFluent.ParamsNested<A> setNewParamLike(int index,InterceptorParams item);
  public TriggerInterceptorFluent.ParamsNested<A> editParam(int index);
  public TriggerInterceptorFluent.ParamsNested<A> editFirstParam();
  public TriggerInterceptorFluent.ParamsNested<A> editLastParam();
  public TriggerInterceptorFluent.ParamsNested<A> editMatchingParam(Predicate<InterceptorParamsBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public InterceptorRef getRef();
  public InterceptorRef buildRef();
  public A withRef(InterceptorRef ref);
  public Boolean hasRef();
  public A withNewRef(String apiVersion,String kind,String name);
  public TriggerInterceptorFluent.RefNested<A> withNewRef();
  public TriggerInterceptorFluent.RefNested<A> withNewRefLike(InterceptorRef item);
  public TriggerInterceptorFluent.RefNested<A> editRef();
  public TriggerInterceptorFluent.RefNested<A> editOrNewRef();
  public TriggerInterceptorFluent.RefNested<A> editOrNewRefLike(InterceptorRef item);
  
  /**
   * This method has been deprecated, please use method buildWebhook instead.
   * @return The buildable object.
   */
  @Deprecated
  public WebhookInterceptor getWebhook();
  public WebhookInterceptor buildWebhook();
  public A withWebhook(WebhookInterceptor webhook);
  public Boolean hasWebhook();
  public TriggerInterceptorFluent.WebhookNested<A> withNewWebhook();
  public TriggerInterceptorFluent.WebhookNested<A> withNewWebhookLike(WebhookInterceptor item);
  public TriggerInterceptorFluent.WebhookNested<A> editWebhook();
  public TriggerInterceptorFluent.WebhookNested<A> editOrNewWebhook();
  public TriggerInterceptorFluent.WebhookNested<A> editOrNewWebhookLike(WebhookInterceptor item);
  public interface BitbucketNested<N> extends Nested<N>,BitbucketInterceptorFluent<TriggerInterceptorFluent.BitbucketNested<N>>{
    public N and();
    public N endBitbucket();
    
  }
  public interface CelNested<N> extends Nested<N>,CELInterceptorFluent<TriggerInterceptorFluent.CelNested<N>>{
    public N and();
    public N endCel();
    
  }
  public interface GithubNested<N> extends Nested<N>,GitHubInterceptorFluent<TriggerInterceptorFluent.GithubNested<N>>{
    public N and();
    public N endGithub();
    
  }
  public interface GitlabNested<N> extends Nested<N>,GitLabInterceptorFluent<TriggerInterceptorFluent.GitlabNested<N>>{
    public N and();
    public N endGitlab();
    
  }
  public interface ParamsNested<N> extends Nested<N>,InterceptorParamsFluent<TriggerInterceptorFluent.ParamsNested<N>>{
    public N and();
    public N endParam();
    
  }
  public interface RefNested<N> extends Nested<N>,InterceptorRefFluent<TriggerInterceptorFluent.RefNested<N>>{
    public N and();
    public N endRef();
    
  }
  public interface WebhookNested<N> extends Nested<N>,WebhookInterceptorFluent<TriggerInterceptorFluent.WebhookNested<N>>{
    public N and();
    public N endWebhook();
    
  }
  
}
